Contribute
===========

- Issue tracker: `https://github.com/LaLogiaDePython/django-menu-generator/issues <https://github.com/LaLogiaDePython/django-menu-generator/issues>`__
- Source code: `https://github.com/LaLogiaDePython/django-menu-generator <https://github.com/LaLogiaDePython/django-menu-generator>`__
